@@ -25,7 +25,7 @@ class SecurityDetails:
         The main method, which calculates everything.
         '''
         result = {}
-        result['message'] = ''
+        # result['message'] = ''
         # ledger = LedgerExecutor(self.logger)
 
         # lots
@@ -34,11 +34,10 @@ class SecurityDetails:
         # result['lots'] = lots
 
         # average price
-        # result['message'] += 'Avg.Price = N/A'
+        # result['avg_price'] += 'N/A'
 
         # yield in the last 12 months
-        # result['yield'] = self.get_yield()
-        result['message'] = self.get_yield()
+        result['yield'] = self.get_yield()
 
         # income (demo)
         # income = self.get_income()
@@ -77,6 +76,7 @@ class SecurityDetails:
         # the accound ends with the symbol name
         ledger_cmd = f'b ^Income and :{self.symbol}$ -b {yield_from} --flat --no-total'
         rows = ledger.run(ledger_cmd)
+        rows = ledger.split_lines(rows)
         return rows
 
     def get_income_balance(self):
@@ -91,6 +91,7 @@ class SecurityDetails:
         # the accound ends with the symbol name
         ledger_cmd = f'b ^Income and :{self.symbol}$ -b {yield_from} --flat -X {self.currency}'
         output = ledger.run(ledger_cmd)
+        output = ledger.split_lines(output)
 
         total = self.get_total_from_ledger_output(output)
         return total
@@ -100,29 +101,41 @@ class SecurityDetails:
         ledger = LedgerExecutor(self.logger)
         cmd = f"b ^Assets and :{self.symbol}$ -X {self.currency}"
         output = ledger.run(cmd)
+        output = ledger.split_lines(output)
         value = self.get_total_from_ledger_output(output)
         return value
 
     def get_total_from_ledger_output(self, output):
         ''' Extract the total value from ledger output '''
         next_line_is_total = False
-        total = None
+        total_line = None
+
+        # Special cases
+        if len(output) == 0:
+            return 0
+        
+        if len(output) == 1:
+            # One-line results don't have totals
+            total_line = output[0]
 
         for i, item in enumerate(output):
             # get total
             if next_line_is_total:
-                total = output[i]
+                total_line = output[i]
                 # self.logger.debug(f'total income for {self.symbol} since {yield_from}: {total}')
             if '------' in output[i]:
                 next_line_is_total = True
 
-        total_numeric = self.extract_total(total)
+        if total_line is None:
+            raise ValueError(f'No total fetched in {output}')
+
+        total_numeric = self.extract_total(total_line)
         return total_numeric
 
     def extract_total(self, total_line):
         ''' Gets the numeric value of the total from the ledger total line '''
-        # from decimal import Decimal
-
+        #self.logger.debug(total_line)
+        
         # Extract the numeric value of the income total.
         total_parts = total_line.split(' ')
         total_numeric = total_parts[0]
